@@ -33,7 +33,9 @@ class AbstractInterface():
     self.__button.set_image_alignment(0.5,0.5)
     self.__button.set_title_alignment(0,0.5)
     self.__button.set_value_alignment(0,0.5)
-    self.__button.connect('clicked', self.__switch)
+    self.__button.connect('clicked', self.__button_clicked)
+    self.__button.tap_and_hold_setup(None, None, 0)
+    self.__button.connect('tap-and-hold', self.__button_tap_and_hold)
     self.__button.connect('destroy', self.__destroy)
 
     self.__smi_cacher = DITPixbufCacher(48)
@@ -47,7 +49,7 @@ class AbstractInterface():
     self.__get_status()
     self.__init_signals()
     self.stop_animation()
-    print self.__name, self.state['value'], self.state['mode'], self.state['strength']
+    #print self.__name, self.state['value'], self.state['mode'], self.state['strength']
     #self.__show_switch_dialog()
 
   def pre_init(self):
@@ -185,11 +187,19 @@ class AbstractInterface():
     self.__set_si(image)
     self.__button.set_value(self.__lcl.get_item(self.state['text'][windex]))
 
-  def __switch(self, button=None, user_data=None):
+  def __button_clicked(self, button=None, user_data=None):
+    self.__switch(self.show_state_dialog)
+    return True
+
+  def __button_tap_and_hold(self, button=None, user_data=None):
+    self.__switch(not(self.show_state_dialog))
+    return True
+
+  def __switch(self, show_dialog):
     if not self.__processing:
       self.__processing = True
       self.start_animation()
-      if self.show_state_dialog:
+      if show_dialog:
         gobject.idle_add(self.__show_switch_dialog)
       else:
         self.__switch_state(int(self.state['value'] == 0))
