@@ -20,12 +20,16 @@ class BTInterface(AbstractInterface):
       'connected': {'name': self.bt_device_signal, 'iface': self.bt_device_iface, 'path': self.bt_device_path, 'args': {'path_keyword': 'path'}}
     },
     'images': ('ifsw_statusarea_bluetooth_off', 'ifsw_statusarea_bluetooth_on', 'ifsw_statusarea_bluetooth_online'),
+    'images_st': ('ifsw_statusarea_bluetooth_online'),
     'text': ('Off', 'On', '<>'),
     'show': (False, True, True),
     'banner': (True, False, True),
-    'value': 0
+    'value': 0,
+    'strength': 0,
+    'modes': ('Connectable', 'Discoverable'),
+    'mode': 0
     }
-    self.interfaces = {'BlueZAdapter': ['org.bluez', self.bt_adapter_path, self.bt_adapter_iface, '']}
+    self.interfaces = {'BlueZAdapter': ['org.bluez', self.bt_adapter_path, self.bt_adapter_iface, '', True]}
     self.connected_device = set()
 
   def process_signal_connected(self, prop, value, **kwargs):
@@ -33,25 +37,31 @@ class BTInterface(AbstractInterface):
       device = kwargs['path'].replace('%s/' % self.bt_adapter_path, '')
       if value:
         self.connected_device.add(device)
-        return 2
+        return 2, None, None
       else:
         self.connected_device.remove(device)
         if len(self.connected_device) == 0:
-          return 1
+          return self.get_status()
         else:
-          return None
+          return None, None, None
     else:
-      return None
+      return None, None, None
 
   def process_signal_on(self, prop, value, **kwargs):
-    if str(prop) == 'Powered':
-      return int(value)
+    prop = str(prop)
+    if (prop == 'Powered'):
+      return int(value), None, None
+    elif (prop == 'Discoverable'):
+      return None, int(value), None
     else:
-      return None
+      return None, None, None
 
   def get_status(self):
-    powered = int(self.get_interface('BlueZAdapter').GetProperties()['Powered'])
-    return powered
+    props = self.get_interface('BlueZAdapter').GetProperties()
+    if props['Powered']:
+      return int(props['Powered']), int(props['Discoverable']), 0
+    else:
+      return 0, 0, 0
 
   def turn_on(self):
     gobject.idle_add(self.run_commands, True)
@@ -62,6 +72,13 @@ class BTInterface(AbstractInterface):
       conndev_iface.Disconnect()
     gobject.idle_add(self.run_commands, False)
 
+  def turn_mode(self, mode):
+    gobject.idle_add(self.run_mode_commands, mode)
+
   def run_commands(self, flag):
     self.get_interface('BlueZAdapter').SetProperty('Powered', flag)
     self.switched()
+
+  def run_mode_commands(self, visible):
+    self.get_interface('BlueZAdapter').SetProperty('Discoverable', bool(visible))
+    self.switched()
