@@ -53,7 +53,7 @@ class GSMInterface(AbstractInterface):
     return result, mode, strength
 
   def process_signal_strength(self, arg1, arg2):
-    return None, None, self.get_strength()
+    return None, None, self.get_strength_value(arg1)
 
   def get_status(self):
     try:
@@ -99,7 +99,7 @@ class GSMInterface(AbstractInterface):
 
   def get_strength(self):
     arg1, arg2, arg3 = self.get_interface('Phone').get_signal_strength()
-    strength = 0
-    if float(arg2) > 0:
-      strength = int(round(min(1.0, float(arg1)/float(arg2))*5))
-    return strength
+    return self.get_strength_value(arg1)
+
+  def get_strength_value(self, value):
+    return int(round(min(1.0, float(value)/100.0)*5))
